package Data::Object::Func::Regexp;

use Data::Object 'Class';

extends 'Data::Object::Func';

our $VERSION = '0.99'; # VERSION

# BUILD
# METHODS

1;

=encoding utf8

=head1 NAME

Data::Object::Func::Regexp

=cut

=head1 ABSTRACT

Functions for RegexpRefs

=cut

=head1 SYNOPSIS

  use Data::Object::Func::Regexp;

=cut

=head1 DESCRIPTION

Data::Object::Func::Regexp is an abstract base class for function classes in
the Data::Object::Func::Regexp space.

=cut
